@@ -198,7 +198,7 @@ class WebHook(object):
 
         commit, author = self.get_commit()
 
-        self.application.db.new("INSERT INTO push VALUES (NULL, ?, ?, ?, ?, DATETIME('NOW'), NULL, NULL)",
+        self.application.db.new("INSERT INTO push VALUES (NULL, ?, ?, ?, ?, DATETIME('NOW'), NULL, NULL, NULL)",
                                 branch_id, commit, author, STATUS_WAITING)
 
 
@@ -263,25 +263,41 @@ class Application(tornado.web.Application):
 
 class Handler(tornado.web.RequestHandler):
     def get(self):
-        self.write("<table border=1 cellpadding=5>")
-        self.write("<tr><th>Status</th><th>Commit</th><th>Author</th><th>Completed</th><th>Duration</th></tr>")
-        for push in self.application.db.all("SELECT * FROM push ORDER BY created DESC LIMIT 25"):
-            if push["started"]:
-                started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
-            else:
-                started = None
-            if push["completed"]:
-                completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
-            else:
-                completed = None
+        push_id = self.get_argument("push", None)
 
-            if started and completed:
-                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
-                           (push["status"], push["commit"], push["author"], completed, (completed - started).seconds))
+        if push_id:
+            push = self.application.db.get_value("SELECT output FROM push WHERE id = ?", push_id)
+            if push:
+                self.finish(push)
             else:
-                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td colspan=2>waiting</td></tr>" %
-                           (push["status"], push["commit"], push["author"]))
-        self.write("</table>")
+                raise tornado.web.HTTPError(404)
+        else:
+            self.write("<table border=1 cellpadding=5>")
+            self.write("<tr><th>Status</th><th>Commit</th><th>Author</th><th>Completed</th><th>Duration</th></tr>")
+            for push in self.application.db.all("SELECT * FROM push ORDER BY created DESC LIMIT 25"):
+                if push["started"]:
+                    started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
+                else:
+                    started = None
+                if push["completed"]:
+                    completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
+                else:
+                    completed = None
+
+                if started and completed:
+                    self.write("<tr>"
+                               "<td>%s</td>"
+                               "<td><a href=\"/?push=%s\">%s</a></td>"
+                               "<td>%s</td>"
+                               "<td>%s</td>"
+                               "<td>%s</td>"
+                               "</tr>" %
+                               (push["status"], push["id"], push["commit"], push["author"], completed,
+                                (completed - started).seconds))
+                else:
+                    self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td colspan=3>waiting</td></tr>" %
+                               (push["status"], push["commit"], push["author"]))
+            self.write("</table>")
 
     def json(self, obj, status=None):
         if status:
